@@ -1,6 +1,8 @@
 import os
 from os.path import join, dirname
 
+import pytest
+
 from api_driver.har_parser import HarParser
 from api_driver.project_generator import ProjectGenerator
 from api_driver.swagger_generate import SwaggerGenerator
@@ -13,7 +15,7 @@ class TestCommand:
         assert os.path.isdir(os.path.join('new_project', "testcase"))
 
     def test_swagger_generate(self):
-        SwaggerGenerator().generate(join(dirname(__file__), 'swagger/swagger.yaml'),
+        SwaggerGenerator().generate(join(dirname(__file__), 'swagger/swagger.json'),
                                     join(dirname(__file__), 'api_object'))
         assert os.path.exists(os.path.join(dirname(__file__) + "/api_object", "users.py"))
 
@@ -22,4 +24,7 @@ class TestCommand:
         testcase_dir = join(dirname(__file__), 'testcase')
         har = HarParser(har_file_path=har_file)
         har.generate_testcase(testcase_path=testcase_dir)
-        assert os.path.exists(os.path.join(dirname(__file__) + "/testcase", "test_demo.py"))
\ No newline at end of file
+        assert os.path.exists(os.path.join(dirname(__file__) + "/testcase", "test_demo.py"))
+
+
+
